%% Controller Case Study
%
% Created by: Christoffer Ofstad 20.01.2014
%
clear
%% Case 1
% Initialize model
simulation_model = ('sim_case_report'); 
sim_length=700;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=4e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[0 0 0]';
constants.real_ice.varying.offset=[0 0 0]';
constants.real_ice.varying.timeon=0;
constants.real_ice.varying.timeoff=0;

%Predictive Force applied
constants.pred.timeon=0;
constants.pred.timeoff=0;
constants.pred.force=[0 0 0]';

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1AFFeta=eta;
Test1AFFtau=tau_actual;
ISE_Test1AFF_eta=total_error(1:3);
ISE_Test1AFF_tau=ISE_thruster.signals.values(end,:)';
Test1AFFmax=max_error;

% With cubic stiffness + AFF
init;
clc
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1cubicAFFeta=eta;
Test1cubicAFFtau=tau_actual;
ISE_Test1cubicAFF_eta=total_error(1:3);
ISE_Test1cubicAFF_tau=ISE_thruster.signals.values(end,:)';
Test1cubicAFFmax=max_error;

% With cubic stiffness + Cubic damping + AFF
init;
clc
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1cubicdampAFFeta=eta;
Test1cubicdampAFFtau=tau_actual;
ISE_Test1cubicdampAFF_eta=total_error(1:3);
ISE_Test1cubicdampAFF_tau=ISE_thruster.signals.values(end,:)';
Test1cubicdampAFFmax=max_error;

% Regular PID
init;
clc
constants.aff.on=0;
constants.controller.Kp3=0;
constants.controller.Kd3=0;
constants.controller.Ki=constants.controller.Ki_PID;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1PIDeta=eta;
Test1PIDtau=tau_actual;
ISE_Test1PID_eta=total_error(1:3);
ISE_Test1PID_tau=ISE_thruster.signals.values(end,:)';
Test1PIDmax=max_error;

%plot eta
figure
subplot(3,1,1)
plot(Test1AFFeta.time,Test1AFFeta.signals.values(:,1));
hold on
plot(Test1cubicAFFeta.time,Test1cubicAFFeta.signals.values(:,1),'g');
hold on
plot(Test1cubicdampAFFeta.time,Test1cubicdampAFFeta.signals.values(:,1),'k');
hold on
plot(Test1PIDeta.time,Test1PIDeta.signals.values(:,1),'r');
xlim([0 Test1AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
h_legend=legend('PID + AFF','PIDP^3+ AFF','PIDP^3D^3 + AFF','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test1AFFeta.time,Test1AFFeta.signals.values(:,2));
hold on
plot(Test1cubicAFFeta.time,Test1cubicAFFeta.signals.values(:,2),'g');
hold on
plot(Test1cubicdampAFFeta.time,Test1cubicdampAFFeta.signals.values(:,2),'k');
hold on
plot(Test1PIDeta.time,Test1PIDeta.signals.values(:,2),'r');
xlim([0 Test1AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(Test1AFFeta.time,Test1AFFeta.signals.values(:,3));
hold on
plot(Test1cubicAFFeta.time,Test1cubicAFFeta.signals.values(:,3),'g');
hold on
plot(Test1cubicdampAFFeta.time,Test1cubicdampAFFeta.signals.values(:,3),'k');
hold on
plot(Test1PIDeta.time,Test1PIDeta.signals.values(:,3),'r');
xlim([0 Test1AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures\Case\Test1_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case1eta.png -r300

%plot tau
figure
subplot(3,1,1)
plot(Test1AFFeta.time,Test1AFFtau.signals.values(:,1));
hold on
plot(Test1cubicAFFeta.time,Test1cubicAFFtau.signals.values(:,1),'g');
hold on
plot(Test1cubicdampAFFeta.time,Test1cubicdampAFFtau.signals.values(:,1),'k');
hold on
plot(Test1PIDeta.time,Test1PIDtau.signals.values(:,1),'r');
xlim([0 Test1AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')

subplot(3,1,2)
plot(Test1AFFeta.time,Test1AFFtau.signals.values(:,2));
hold on
plot(Test1cubicAFFeta.time,Test1cubicAFFtau.signals.values(:,2),'g');
hold on
plot(Test1cubicdampAFFeta.time,Test1cubicdampAFFtau.signals.values(:,2),'k');
hold on
plot(Test1PIDeta.time,Test1PIDtau.signals.values(:,2),'r');
xlim([0 Test1AFFeta.time(end)]);ylim([-2e5 7e5]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(Test1AFFeta.time,Test1AFFtau.signals.values(:,3));
hold on
plot(Test1cubicAFFeta.time,Test1cubicAFFtau.signals.values(:,3),'g');
hold on
plot(Test1cubicdampAFFeta.time,Test1cubicdampAFFtau.signals.values(:,3),'k');
hold on
plot(Test1PIDeta.time,Test1PIDtau.signals.values(:,3),'r');
xlim([0 Test1AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
h_legend=legend('PID + AFF','PIDP^3+ AFF','PIDP^3D^3 + AFF','PID','Location','SouthEast');
set(h_legend,'FontSize',10)
saveas(gcf, 'figures/Case/Test1_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case1tau.png -r300

%% Case 2
% Initialize model
simulation_model = ('sim_case_report'); 
sim_length=700;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=6e5;
displacement=[40 4];
AoA_ice=10;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[0 0 0]';
constants.real_ice.varying.offset=[0 0 0]';
constants.real_ice.varying.timeon=0;
constants.real_ice.varying.timeoff=0;

%Predictive Force applied
constants.pred.timeon=0;
constants.pred.timeoff=0;
constants.pred.force=[0 0 0]';

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2AFFeta=eta;
Test2AFFtau=tau_actual;
ISE_Test2AFF_eta=total_error(1:3);
ISE_Test2AFF_tau=ISE_thruster.signals.values(end,:)';
Test2AFFmax=max_error;

% With cubic stiffness + AFF
init;
clc
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2cubicAFFeta=eta;
Test2cubicAFFtau=tau_actual;
ISE_Test2cubicAFF_eta=total_error(1:3);
ISE_Test2cubicAFF_tau=ISE_thruster.signals.values(end,:)';
Test2cubicAFFmax=max_error;

% With cubic stiffness + Cubic damping + AFF
init;
clc
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2cubicdampAFFeta=eta;
Test2cubicdampAFFtau=tau_actual;
ISE_Test2cubicdampAFF_eta=total_error(1:3);
ISE_Test2cubicdampAFF_tau=ISE_thruster.signals.values(end,:)';
Test2cubicdampAFFmax=max_error;

% Regular PID
init;
clc
constants.aff.on=0;
constants.controller.Kp3=0;
constants.controller.Kd3=0;
constants.controller.Ki=constants.controller.Ki_PID;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2PIDeta=eta;
Test2PIDtau=tau_actual;
ISE_Test2PID_eta=total_error(1:3);
ISE_Test2PID_tau=ISE_thruster.signals.values(end,:)';
Test2PIDmax=max_error;

%plot eta
figure
subplot(3,1,1)
plot(Test2AFFeta.time,Test2AFFeta.signals.values(:,1));
hold on
plot(Test2cubicAFFeta.time,Test2cubicAFFeta.signals.values(:,1),'g');
hold on
plot(Test2cubicdampAFFeta.time,Test2cubicdampAFFeta.signals.values(:,1),'k');
hold on
plot(Test2PIDeta.time,Test2PIDeta.signals.values(:,1),'r');
xlim([0 Test2AFFeta.time(end)]);ylim([-20 10]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
h_legend=legend('PID + AFF','PIDP^3+ AFF','PIDP^3D^3 + AFF','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test2AFFeta.time,Test2AFFeta.signals.values(:,2));
hold on
plot(Test2cubicAFFeta.time,Test2cubicAFFeta.signals.values(:,2),'g');
hold on
plot(Test2cubicdampAFFeta.time,Test2cubicdampAFFeta.signals.values(:,2),'k');
hold on
plot(Test2PIDeta.time,Test2PIDeta.signals.values(:,2),'r');
xlim([0 Test2AFFeta.time(end)]);ylim([-1 1]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(Test2AFFeta.time,Test2AFFeta.signals.values(:,3));
hold on
plot(Test2cubicAFFeta.time,Test2cubicAFFeta.signals.values(:,3),'g');
hold on
plot(Test2cubicdampAFFeta.time,Test2cubicdampAFFeta.signals.values(:,3),'k');
hold on
plot(Test2PIDeta.time,Test2PIDeta.signals.values(:,3),'r');
xlim([0 Test2AFFeta.time(end)]);ylim([-2.5 1]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures\Case\Test2_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case2eta.png -r300

%plot tau
figure
subplot(3,1,1)
plot(Test2AFFeta.time,Test2AFFtau.signals.values(:,1));
hold on
plot(Test2cubicAFFeta.time,Test2cubicAFFtau.signals.values(:,1),'g');
hold on
plot(Test2cubicdampAFFeta.time,Test2cubicdampAFFtau.signals.values(:,1),'k');
hold on
plot(Test2PIDeta.time,Test2PIDtau.signals.values(:,1),'r');
xlim([0 Test2AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
h_legend=legend('PID + AFF','PIDP^3+ AFF','PIDP^3D^3 + AFF','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test2AFFeta.time,Test2AFFtau.signals.values(:,2));
hold on
plot(Test2cubicAFFeta.time,Test2cubicAFFtau.signals.values(:,2),'g');
hold on
plot(Test2cubicdampAFFeta.time,Test2cubicdampAFFtau.signals.values(:,2),'k');
hold on
plot(Test2PIDeta.time,Test2PIDtau.signals.values(:,2),'r');
xlim([0 Test2AFFeta.time(end)]);ylim([-1e5 3e5]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(Test2AFFeta.time,Test2AFFtau.signals.values(:,3));
hold on
plot(Test2cubicAFFeta.time,Test2cubicAFFtau.signals.values(:,3),'g');
hold on
plot(Test2cubicdampAFFeta.time,Test2cubicdampAFFtau.signals.values(:,3),'k');
hold on
plot(Test2PIDeta.time,Test2PIDtau.signals.values(:,3),'r');
xlim([0 Test2AFFeta.time(end)]);ylim([-2e6 4e6]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
saveas(gcf, 'figures\Case\Test2_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case2tau.png -r300

%% Case 3
% Initialize model
simulation_model = ('sim_case_report'); 
sim_length=700;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[2e5 2e5 4e7]';
constants.real_ice.varying.offset=[-3e5 4e5 1e7]';
constants.real_ice.varying.timeon=200;
constants.real_ice.varying.timeoff=400;

%Predictive Force applied
constants.pred.timeon=0;
constants.pred.timeoff=0;
constants.pred.force=[0 0 0]';

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test3AFFeta=eta;
Test3AFFtau=tau_actual;
ISE_Test3AFF_eta=total_error(1:3);
ISE_Test3AFF_tau=ISE_thruster.signals.values(end,:)';
Test3AFFmax=max_error;

% With cubic stiffness + AFF
init;
clc
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test3cubicAFFeta=eta;
Test3cubicAFFtau=tau_actual;
ISE_Test3cubicAFF_eta=total_error(1:3);
ISE_Test3cubicAFF_tau=ISE_thruster.signals.values(end,:)';
Test3cubicAFFmax=max_error;

% With cubic stiffness + Cubic damping + AFF
init;
clc
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test3cubicdampAFFeta=eta;
Test3cubicdampAFFtau=tau_actual;
ISE_Test3cubicdampAFF_eta=total_error(1:3);
ISE_Test3cubicdampAFF_tau=ISE_thruster.signals.values(end,:)';
Test3cubicdampAFFmax=max_error;

% Regular PID
init;
clc
constants.aff.on=0;
constants.controller.Kp3=0;
constants.controller.Kd3=0;
constants.controller.Ki=constants.controller.Ki_PID;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test3PIDeta=eta;
Test3PIDtau=tau_actual;
ISE_Test3PID_eta=total_error(1:3);
ISE_Test3PID_tau=ISE_thruster.signals.values(end,:)';
Test3PIDmax=max_error;

%plot eta
figure
subplot(3,1,1)
plot(Test3AFFeta.time,Test3AFFeta.signals.values(:,1));
hold on
plot(Test3cubicAFFeta.time,Test3cubicAFFeta.signals.values(:,1),'g');
hold on
plot(Test3cubicdampAFFeta.time,Test3cubicdampAFFeta.signals.values(:,1),'k');
hold on
plot(Test3PIDeta.time,Test3PIDeta.signals.values(:,1),'r');
xlim([0 Test3AFFeta.time(end)]);ylim([-6 5]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
h_legend=legend('PID + AFF','PIDP^3+ AFF','PIDP^3D^3 + AFF','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test3AFFeta.time,Test3AFFeta.signals.values(:,2));
hold on
plot(Test3cubicAFFeta.time,Test3cubicAFFeta.signals.values(:,2),'g');
hold on
plot(Test3cubicdampAFFeta.time,Test3cubicdampAFFeta.signals.values(:,2),'k');
hold on
plot(Test3PIDeta.time,Test3PIDeta.signals.values(:,2),'r');
xlim([0 Test3AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(Test3AFFeta.time,Test3AFFeta.signals.values(:,3));
hold on
plot(Test3cubicAFFeta.time,Test3cubicAFFeta.signals.values(:,3),'g');
hold on
plot(Test3cubicdampAFFeta.time,Test3cubicdampAFFeta.signals.values(:,3),'k');
hold on
plot(Test3PIDeta.time,Test3PIDeta.signals.values(:,3),'r');
xlim([0 Test3AFFeta.time(end)]);ylim([-15 20]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures\Case\Test3_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case3eta.png -r300

%plot tau
figure
subplot(3,1,1)
plot(Test3AFFeta.time,Test3AFFtau.signals.values(:,1));
hold on
plot(Test3cubicAFFeta.time,Test3cubicAFFtau.signals.values(:,1),'g');
hold on
plot(Test3cubicdampAFFeta.time,Test3cubicdampAFFtau.signals.values(:,1),'k');
hold on
plot(Test3PIDeta.time,Test3PIDtau.signals.values(:,1),'r');
xlim([0 Test3AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
h_legend=legend('PID + AFF','PIDP^3+ AFF','PIDP^3D^3 + AFF','PID','Location','NorthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test3AFFeta.time,Test3AFFtau.signals.values(:,2));
hold on
plot(Test3cubicAFFeta.time,Test3cubicAFFtau.signals.values(:,2),'g');
hold on
plot(Test3cubicdampAFFeta.time,Test3cubicdampAFFtau.signals.values(:,2),'k');
hold on
plot(Test3PIDeta.time,Test3PIDtau.signals.values(:,2),'r');
xlim([0 Test3AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(Test3AFFeta.time,Test3AFFtau.signals.values(:,3));
hold on
plot(Test3cubicAFFeta.time,Test3cubicAFFtau.signals.values(:,3),'g');
hold on
plot(Test3cubicdampAFFeta.time,Test3cubicdampAFFtau.signals.values(:,3),'k');
hold on
plot(Test3PIDeta.time,Test3PIDtau.signals.values(:,3),'r');
xlim([0 Test3AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
saveas(gcf, 'figures\Case\Test3_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case3tau.png -r300

%% Case 4
% Initialize model
simulation_model = ('sim_case_report'); 
sim_length=700;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[2e5 2e5 4e7]';
constants.real_ice.varying.offset=[-3e5 4e5 1e7]';
constants.real_ice.varying.timeon=200;
constants.real_ice.varying.timeoff=400;

%Predictive Force applied
constants.pred.timeon=0;
constants.pred.timeoff=0;
constants.pred.force=[0 0 0]';

%Wave filter
constants.wavefilter.on=1;
constants.selective.on=1;

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4AFFeta=eta;
Test4AFFtau=tau_actual;
ISE_Test4AFF_eta=total_error(1:3);
ISE_Test4AFF_tau=ISE_thruster.signals.values(end,:)';
Test4AFFmax=max_error;

% With uncertain AFF
constants.aff.gain.acceleration=.75*constants.vessel.M;
constants.aff.gain.velocity=.9*constants.vessel.D;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4uncertainAFFeta=eta;
Test4uncertainAFFtau=tau_actual;
ISE_Test4uncertainAFF_eta=total_error(1:3);
ISE_Test4uncertainAFF_tau=ISE_thruster.signals.values(end,:)';
Test4uncertainAFFmax=max_error;

% Regular PID
constants.aff.on=0;
constants.controller.Ki=constants.controller.Ki_PID;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4PIDeta=eta;
Test4PIDtau=tau_actual;
ISE_Test4PID_eta=total_error(1:3);
ISE_Test4PID_tau=ISE_thruster.signals.values(end,:)';
Test4PIDmax=max_error;

%plot eta
figure
subplot(3,1,1)
plot(Test4AFFeta.time,Test4AFFeta.signals.values(:,1));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFeta.signals.values(:,1),'g');
hold on
plot(Test4PIDeta.time,Test4PIDeta.signals.values(:,1),'r');
xlim([0 Test4AFFeta.time(end)]);ylim([-6 5]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
h_legend=legend('PID + AFF','PID+ AFF w/ model error','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test4AFFeta.time,Test4AFFeta.signals.values(:,2));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFeta.signals.values(:,2),'g');
hold on
plot(Test4PIDeta.time,Test4PIDeta.signals.values(:,2),'r');
xlim([0 Test4AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(Test4AFFeta.time,Test4AFFeta.signals.values(:,3));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFeta.signals.values(:,3),'g');
hold on
plot(Test4PIDeta.time,Test4PIDeta.signals.values(:,3),'r');
xlim([0 Test4AFFeta.time(end)]);ylim([-15 29]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures\Case\Test4_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case4eta.png -r300

%plot tau
figure
subplot(3,1,1)
plot(Test4AFFeta.time,Test4AFFtau.signals.values(:,1));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFtau.signals.values(:,1),'g');
hold on
plot(Test4PIDeta.time,Test4PIDtau.signals.values(:,1),'r');
xlim([0 Test4AFFeta.time(end)]);ylim([-5e5 10e5]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
h_legend=legend('PID + AFF','PID+ AFF w/ model error','PID','Location','NorthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test4AFFeta.time,Test4AFFtau.signals.values(:,2));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFtau.signals.values(:,2),'g');
hold on
plot(Test4PIDeta.time,Test4PIDtau.signals.values(:,2),'r');
xlim([0 Test4AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(Test4AFFeta.time,Test4AFFtau.signals.values(:,3));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFtau.signals.values(:,3),'g');
hold on
plot(Test4PIDeta.time,Test4PIDtau.signals.values(:,3),'r');
xlim([0 Test4AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
saveas(gcf, 'figures\Case\Test4_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case4tau.png -r300

%% Case 5
% Initialize model
simulation_model = ('sim_case_report'); 
sim_length=700;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=4e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[0 0 0]';
constants.real_ice.varying.offset=[0 0 0]';
constants.real_ice.varying.timeon=0;
constants.real_ice.varying.timeoff=0;

%Predictive Force applied
d_pred=displacement; 
t=2.5;
gamma=2.25;
constants.pred.timeoff=constants.real_ice.timeon;
constants.pred.timeon=constants.pred.timeoff-t;
constants.pred.force=pred_force(gamma*F_ice,displacement,AoA_ice);

%Wave filter
constants.wavefilter.on=1;
constants.selective.on=1;

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test5AFFeta=eta;
Test5AFFtau=tau_actual;
ISE_Test5AFF_eta=total_error(1:3);
ISE_Test5AFF_tau=ISE_thruster.signals.values(end,:)';
Test5AFFmax=max_error;

% With uncertain AFF
constants.aff.gain.acceleration=.75*constants.vessel.M;
constants.aff.gain.velocity=.9*constants.vessel.D;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test5uncertainAFFeta=eta;
Test5uncertainAFFtau=tau_actual;
ISE_Test5uncertainAFF_eta=total_error(1:3);
ISE_Test5uncertainAFF_tau=ISE_thruster.signals.values(end,:)';
Test5uncertainAFFmax=max_error;

% Regular PID
constants.aff.on=0;
constants.controller.Ki=constants.controller.Ki_PID;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test5PIDeta=eta;
Test5PIDtau=tau_actual;
ISE_Test5PID_eta=total_error(1:3);
ISE_Test5PID_tau=ISE_thruster.signals.values(end,:)';
Test5PIDmax=max_error;

%plot eta
figure
subplot(3,1,1)
plot(Test5AFFeta.time,Test5AFFeta.signals.values(:,1));
hold on
plot(Test5uncertainAFFeta.time,Test5uncertainAFFeta.signals.values(:,1),'g');
hold on
plot(Test5PIDeta.time,Test5PIDeta.signals.values(:,1),'r');
xlim([0 Test5AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
h_legend=legend('PID + AFF','PID+ AFF w/ model error','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test5AFFeta.time,Test5AFFeta.signals.values(:,2));
hold on
plot(Test5uncertainAFFeta.time,Test5uncertainAFFeta.signals.values(:,2),'g');
hold on
plot(Test5PIDeta.time,Test5PIDeta.signals.values(:,2),'r');
xlim([0 Test5AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(Test5AFFeta.time,Test5AFFeta.signals.values(:,3));
hold on
plot(Test5uncertainAFFeta.time,Test5uncertainAFFeta.signals.values(:,3),'g');
hold on
plot(Test5PIDeta.time,Test5PIDeta.signals.values(:,3),'r');
xlim([0 Test5AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures\Case\Test5_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case5eta.png -r300

%plot tau
figure
subplot(3,1,1)
plot(Test5AFFeta.time,Test5AFFtau.signals.values(:,1));
hold on
plot(Test5uncertainAFFeta.time,Test5uncertainAFFtau.signals.values(:,1),'g');
hold on
plot(Test5PIDeta.time,Test5PIDtau.signals.values(:,1),'r');
xlim([0 Test5AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
h_legend=legend('PID + AFF','PID+ AFF w/ model error','PID','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test5AFFeta.time,Test5AFFtau.signals.values(:,2));
hold on
plot(Test5uncertainAFFeta.time,Test5uncertainAFFtau.signals.values(:,2),'g');
hold on
plot(Test5PIDeta.time,Test5PIDtau.signals.values(:,2),'r');
xlim([0 Test5AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(Test5AFFeta.time,Test5AFFtau.signals.values(:,3));
hold on
plot(Test5uncertainAFFeta.time,Test5uncertainAFFtau.signals.values(:,3),'g');
hold on
plot(Test5PIDeta.time,Test5PIDtau.signals.values(:,3),'r');
xlim([0 Test5AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
saveas(gcf, 'figures\Case\Test5_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case5tau.png -r300
       
%% ISE
format shortG
%Separate each case with NaN's
ISE=[ISE_Test1AFF_eta', ISE_Test1AFF_tau';
        ISE_Test1cubicAFF_eta',ISE_Test1cubicAFF_tau';
        ISE_Test1cubicdampAFF_eta',ISE_Test1cubicdampAFF_tau';
        ISE_Test1PID_eta',ISE_Test1PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test2AFF_eta', ISE_Test2AFF_tau';
        ISE_Test2cubicAFF_eta',ISE_Test2cubicAFF_tau';
        ISE_Test2cubicdampAFF_eta',ISE_Test2cubicdampAFF_tau';
        ISE_Test2PID_eta',ISE_Test2PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test3AFF_eta', ISE_Test3AFF_tau';
        ISE_Test3cubicAFF_eta',ISE_Test3cubicAFF_tau';
        ISE_Test3cubicdampAFF_eta',ISE_Test3cubicdampAFF_tau';
        ISE_Test3PID_eta',ISE_Test3PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test4AFF_eta', ISE_Test4AFF_tau';
        ISE_Test4uncertainAFF_eta',ISE_Test4uncertainAFF_tau';
        ISE_Test4PID_eta',ISE_Test4PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test5AFF_eta', ISE_Test5AFF_tau';
        ISE_Test5uncertainAFF_eta',ISE_Test5uncertainAFF_tau';
        ISE_Test5PID_eta',ISE_Test5PID_tau'];
ISE=[ISE(:,1:3) ISE(:,4:6)./1e12];
matrix2lyx(ISE, 'ISE_case_study.lyx')

ISEratio=[ISE_Test1AFF_eta'./ISE_Test1PID_eta', ISE_Test1AFF_tau'./ISE_Test1PID_tau';
        ISE_Test1cubicAFF_eta'./ISE_Test1PID_eta',ISE_Test1cubicAFF_tau'./ISE_Test1PID_tau';
        ISE_Test1cubicdampAFF_eta'./ISE_Test1PID_eta',ISE_Test1cubicdampAFF_tau'./ISE_Test1PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test2AFF_eta'./ISE_Test2PID_eta', ISE_Test2AFF_tau'./ISE_Test2PID_tau';
        ISE_Test2cubicAFF_eta'./ISE_Test2PID_eta',ISE_Test2cubicAFF_tau'./ISE_Test2PID_tau';
        ISE_Test2cubicdampAFF_eta'./ISE_Test2PID_eta',ISE_Test2cubicdampAFF_tau'./ISE_Test2PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test3AFF_eta'./ISE_Test3PID_eta', ISE_Test3AFF_tau'./ISE_Test3PID_tau';
        ISE_Test3cubicAFF_eta'./ISE_Test3PID_eta',ISE_Test3cubicAFF_tau'./ISE_Test3PID_tau';
        ISE_Test3cubicdampAFF_eta'./ISE_Test3PID_eta',ISE_Test3cubicdampAFF_tau'./ISE_Test3PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test4AFF_eta'./ISE_Test4PID_eta', ISE_Test4AFF_tau'./ISE_Test4PID_tau';
        ISE_Test4uncertainAFF_eta'./ISE_Test4PID_eta',ISE_Test4uncertainAFF_tau'./ISE_Test4PID_tau';
        NaN,NaN,NaN,NaN,NaN,NaN; 
        ISE_Test5AFF_eta'./ISE_Test5PID_eta', ISE_Test5AFF_tau'./ISE_Test5PID_tau';
        ISE_Test5uncertainAFF_eta'./ISE_Test5PID_eta',ISE_Test5uncertainAFF_tau'./ISE_Test5PID_tau';
];
matrix2lyx(ISEratio, 'ISE_case_ratio.lyx')
%%
clear total_error max_error eta tau_actual ISE_thruster ISE_eta tout...
      h_legend