%% AFF controller with filtered acceleration feedback
%
% Created by: Christoffer Ofstad 20.01.2014
%
clear

%% Case 4
% Initialize model
simulation_model = ('sim_case_report'); 
simulation_model_lpaff = ('sim_case_report_lpaff');
simulation_model_notchaff = ('sim_case_report_notchaff'); 
sim_length=700;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[2e5 2e5 4e7]';
constants.real_ice.varying.offset=[-3e5 4e5 1e7]';
constants.real_ice.varying.timeon=200;
constants.real_ice.varying.timeoff=400;

%Predictive Force applied
constants.pred.timeon=0;
constants.pred.timeoff=0;
constants.pred.force=[0 0 0]';

%Wave filter
constants.wavefilter.on=1;
constants.selective.on=1;

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4AFFeta=eta;
Test4AFFtau=tau_actual;
ISE_Test4AFF_eta=total_error(1:3);
ISE_Test4AFF_tau=ISE_thruster.signals.values(end,:)';
Test4AFFmax=max_error;

% % With uncertain AFF
sim(simulation_model_lpaff);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4uncertainAFFeta=eta;
Test4uncertainAFFtau=tau_actual;
ISE_Test4uncertainAFF_eta=total_error(1:3);
ISE_Test4uncertainAFF_tau=ISE_thruster.signals.values(end,:)';
Test4uncertainAFFmax=max_error;


% Regular PID
sim(simulation_model_notchaff);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4PIDeta=eta;
Test4PIDtau=tau_actual;
ISE_Test4PID_eta=total_error(1:3);
ISE_Test4PID_tau=ISE_thruster.signals.values(end,:)';
Test4PIDmax=max_error;

%plot eta
figure
subplot(3,1,1)
plot(Test4AFFeta.time,Test4AFFeta.signals.values(:,1));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFeta.signals.values(:,1),'g');
hold on
plot(Test4PIDeta.time,Test4PIDeta.signals.values(:,1),'r');
xlim([0 Test4AFFeta.time(end)]);ylim([-6 5]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
h_legend=legend('PID + AFF','PID + low-pass AFF','PID + notch AFF','Location','SouthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test4AFFeta.time,Test4AFFeta.signals.values(:,2));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFeta.signals.values(:,2),'g');
hold on
plot(Test4PIDeta.time,Test4PIDeta.signals.values(:,2),'r');
xlim([0 Test4AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(Test4AFFeta.time,Test4AFFeta.signals.values(:,3));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFeta.signals.values(:,3),'g');
hold on
plot(Test4PIDeta.time,Test4PIDeta.signals.values(:,3),'r');
xlim([0 Test4AFFeta.time(end)]);ylim([-15 29]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')

set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case4_aff_lp_and_notch_eta.png -r300

%plot tau
figure
subplot(3,1,1)
plot(Test4AFFeta.time,Test4AFFtau.signals.values(:,1));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFtau.signals.values(:,1),'g');
hold on
plot(Test4PIDeta.time,Test4PIDtau.signals.values(:,1),'r');
xlim([0 Test4AFFeta.time(end)]);ylim([-5e5 10e5]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
h_legend=legend('PID + AFF','PID + low-pass AFF','PID + notch AFF','Location','NorthEast');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test4AFFeta.time,Test4AFFtau.signals.values(:,2));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFtau.signals.values(:,2),'g');
hold on
plot(Test4PIDeta.time,Test4PIDtau.signals.values(:,2),'r');
xlim([0 Test4AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(Test4AFFeta.time,Test4AFFtau.signals.values(:,3));
hold on
plot(Test4uncertainAFFeta.time,Test4uncertainAFFtau.signals.values(:,3),'g');
hold on
plot(Test4PIDeta.time,Test4PIDtau.signals.values(:,3),'r');
xlim([0 Test4AFFeta.time(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    

set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\Case4_aff_lp_and_notch_tau.png -r300
