%% Find tuning parameters for notch wave filter
%
% Created by Christoffer Ofstad, 20.02.2014

% Initialize model
simulation_model = ('sim_case_report'); 
sim_length=700;
init
clc
find_available_thrust
delta=5;

%Constant Ice Force applied
F_ice=0e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[0 0 0]';
constants.real_ice.varying.offset=[0 0 0]';
constants.real_ice.varying.timeon=0;
constants.real_ice.varying.timeoff=0;

%Predictive Force applied
constants.pred.timeon=0;
constants.pred.timeoff=0;
constants.pred.force=[0 0 0]';

%Find error without wave filter
sim(simulation_model);
[total_error_no_pred, ~] = error_sampling(eta, ISE_eta);
total_thrust=ISE_thruster.signals.values(end,:)';

%Wave filter
constants.wavefilter.on=1;

% With AFF
constants.controller.Kp3=0;
constants.controller.Kd3=0;

%Initialize limits for heading
Q_min=.6;
Q_max=1.2;
Q=Q_min:(Q_max-Q_min)/(delta-1):Q_max;

%Initialize limits for predicted position of impact
zeta_min=.01;
zeta_max=.4;
zeta=zeta_min:(zeta_max-zeta_min)/(delta-1):zeta_max;


%% Time vs Force
%Initialize error vector
error_pos=zeros(delta);
error_thrust_x=zeros(delta);
error_thrust_y=zeros(delta);
error_thrust_psi=zeros(delta);
error_thrust_x_WA=zeros(delta);
count=0;
start_time=tic;
for i=1:length(Q)
    for j=1:length(zeta)
        constants.wavefilter.zeta=zeta(j);
        constants.wavefilter.Q=Q(i);
        %Simulation
        sim_start=tic;
        sim(simulation_model);
        sim_time=toc(sim_start);
        [total_error, ~] = error_sampling(eta, ISE_eta);
        error_pos(i,j)=total_error(4)/total_error_no_pred(4);
        error_thrust_x(i,j)=ISE_thruster.signals.values(end,1)/total_thrust(1);
        error_thrust_y(i,j)=ISE_thruster.signals.values(end,2)/total_thrust(2);
        error_thrust_psi(i,j)=ISE_thruster.signals.values(end,3)/total_thrust(3);
        error_thrust_x_WA(i,j)=.8*error_thrust_x(i,j)+.2* error_pos(i,j);
        count=count+1;
        clc
        string = [num2str(round(100*((count)/(length(Q)*length(zeta))))),'% complete'];
        string2= [secs2hms(abs(sim_time*(length(Q)*length(zeta))-toc(start_time))),' remaining'];
        disp(string);
        disp(string2);
    end
end

figure(33)
contour3(Q,zeta,error_pos,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('position error ratio')
set_font


figure(441)
contour3(Q,zeta,error_thrust_x,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('heading error ratio')
set_font


figure(442)
contour3(Q,zeta,error_thrust_y,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('heading error ratio')
set_font


figure(443)
contour3(Q,zeta,error_thrust_psi,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('heading error ratio')
set_font


figure(55)
contour3(Q,zeta,error_thrust_x_WA,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('heading error ratio')
set_font

figure(66)
contour3(Q,zeta,error_thrust_x,1000)
hold on
contour3(Q,zeta,error_pos,1000)
xlabel('Q');ylabel('\zeta');zlabel('error ratio')
set_font
