%% Process and plot data logged from MT simulations
%
% Created by: Christoffer Ofstad 20.02.2014
%
%% Case 1
% Disturbance force: F_ice=1e5, displacement=[40 9], AoI=80 degrees
% Yields bias term in MT simulator [1.8 10 9.6] (ton), where the moment 
% has been scaled to ton by dividing by the mean lever arm=34.75 meter.

%Choose logfile, remove decimal commas and convert to dataset
%With AFB
Logfile = 'Test1AFB.csv';
csvfix
[ds_Test1AFB] = create_log_dataset();
save('LogData\Test1AFB.mat','ds_Test1AFB');
%With Cubic
Logfile = 'Test1cubic.csv';
csvfix
[ds_Test1cubic] = create_log_dataset();
save('LogData\Test1cubic.mat','ds_Test1cubic');
%With Cubic+AFB
Logfile = 'Test1cubicAFB.csv';
csvfix
[ds_Test1cubicAFB] = create_log_dataset();
save('LogData\Test1cubicAFB.mat','ds_Test1cubicAFB');
%Without AFB
Logfile = 'Test1noAFB.csv';
csvfix
[ds_Test1noAFB] = create_log_dataset();
save('LogData\Test1noAFB.mat','ds_Test1noAFB');


%Rotate to NED-frame, first dataset
for i=1:length(ds_Test1AFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test1AFB.Debug3(i))*...
      [ds_Test1AFB.Debug1(i),ds_Test1AFB.Debug2(i),ds_Test1AFB.Debug3(i)]';
    ds_Test1AFB.Debug1(i)=a(1);
    ds_Test1AFB.Debug2(i)=a(2);
    ds_Test1AFB.Debug3(i)=a(3);
end

%Rotate to NED-frame, second dataset
for i=1:length(ds_Test1noAFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test1noAFB.Debug3(i))*...
      [ds_Test1noAFB.Debug1(i),ds_Test1noAFB.Debug2(i),ds_Test1noAFB.Debug3(i)]';
    ds_Test1noAFB.Debug1(i)=a(1);
    ds_Test1noAFB.Debug2(i)=a(2);
    ds_Test1noAFB.Debug3(i)=a(3);
end

%Rotate to NED-frame, third dataset
for i=1:length(ds_Test1cubic.time0)
    a=Rzyx(0,0,pi/180*ds_Test1cubic.Debug3(i))*...
      [ds_Test1cubic.Debug1(i),ds_Test1cubic.Debug2(i),ds_Test1cubic.Debug3(i)]';
    ds_Test1cubic.Debug1(i)=a(1);
    ds_Test1cubic.Debug2(i)=a(2);
    ds_Test1cubic.Debug3(i)=a(3);
end

%Rotate to NED-frame, fourth dataset
for i=1:length(ds_Test1cubicAFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test1cubicAFB.Debug3(i))*...
      [ds_Test1cubicAFB.Debug1(i),ds_Test1cubicAFB.Debug2(i),ds_Test1cubicAFB.Debug3(i)]';
    ds_Test1cubicAFB.Debug1(i)=a(1);
    ds_Test1cubicAFB.Debug2(i)=a(2);
    ds_Test1cubicAFB.Debug3(i)=a(3);
end

%Scale from ton to N and Nm, first dataset
Momentarm=34.75;
Newton_per_ton=9806.65;
ds_Test1AFB.Debug4=Newton_per_ton.*ds_Test1AFB.Debug4;
ds_Test1AFB.Debug5=Newton_per_ton.*ds_Test1AFB.Debug5;
ds_Test1AFB.Debug6=Newton_per_ton*Momentarm.*ds_Test1AFB.Debug6;

%Scale from ton to N and Nm, first dataset
ds_Test1noAFB.Debug4=Newton_per_ton.*ds_Test1noAFB.Debug4;
ds_Test1noAFB.Debug5=Newton_per_ton.*ds_Test1noAFB.Debug5;
ds_Test1noAFB.Debug6=Newton_per_ton*Momentarm.*ds_Test1noAFB.Debug6;

%Scale from ton to N and Nm, third dataset
ds_Test1cubic.Debug4=Newton_per_ton.*ds_Test1cubic.Debug4;
ds_Test1cubic.Debug5=Newton_per_ton.*ds_Test1cubic.Debug5;
ds_Test1cubic.Debug6=Newton_per_ton*Momentarm.*ds_Test1cubic.Debug6;

%Scale from ton to N and Nm, fourth dataset
ds_Test1cubicAFB.Debug4=Newton_per_ton.*ds_Test1cubicAFB.Debug4;
ds_Test1cubicAFB.Debug5=Newton_per_ton.*ds_Test1cubicAFB.Debug5;
ds_Test1cubicAFB.Debug6=Newton_per_ton*Momentarm.*ds_Test1cubicAFB.Debug6;

%Low-pass filter noisy signal
[ds_Test1noAFB] = lowpass(ds_Test1noAFB);
[ds_Test1AFB] = lowpass(ds_Test1AFB);
[ds_Test1cubicAFB] = lowpass(ds_Test1cubicAFB);
[ds_Test1cubic] = lowpass(ds_Test1cubic);

%Sync datasets
test_set_a=ds_Test1AFB.Debug4;
sample_a=0;
for i=1:length(test_set_a)
    if abs(test_set_a(i))>100
        sample_a=i;
        break;
    end
end
test_set_b=ds_Test1cubic.Debug4;
sample_b=0;
for i=1:length(test_set_b)
    if abs(test_set_b(i))>100
        sample_b=i;
        break;
    end
end
test_set_c=ds_Test1cubicAFB.Debug4;
sample_c=0;
for i=1:length(test_set_c)
    if abs(test_set_c(i))>100
        sample_c=i;
        break;
    end
end
test_set_d=ds_Test1noAFB.Debug4;
sample_d=0;
for i=1:length(test_set_d)
    if abs(test_set_d(i))>100
        sample_d=i;
        break;
    end
end

min_sample=min([sample_a, sample_b, sample_c, sample_d]);

if sample_a==min_sample
    sample=sample_b-min_sample;
    ds_Test1cubic.Debug1=ds_Test1cubic.Debug1(sample:end);
    ds_Test1cubic.Debug2=ds_Test1cubic.Debug2(sample:end);
    ds_Test1cubic.Debug3=ds_Test1cubic.Debug3(sample:end);
    ds_Test1cubic.Debug4=ds_Test1cubic.Debug4(sample:end);
    ds_Test1cubic.Debug5=ds_Test1cubic.Debug5(sample:end);
    ds_Test1cubic.Debug6=ds_Test1cubic.Debug6(sample:end);
    ds_Test1cubic.time0=ds_Test1cubic.time0(1:length(ds_Test1cubic.Debug1));
    sample=sample_c-min_sample;
    ds_Test1cubicAFB.Debug1=ds_Test1cubicAFB.Debug1(sample:end);
    ds_Test1cubicAFB.Debug2=ds_Test1cubicAFB.Debug2(sample:end);
    ds_Test1cubicAFB.Debug3=ds_Test1cubicAFB.Debug3(sample:end);
    ds_Test1cubicAFB.Debug4=ds_Test1cubicAFB.Debug4(sample:end);
    ds_Test1cubicAFB.Debug5=ds_Test1cubicAFB.Debug5(sample:end);
    ds_Test1cubicAFB.Debug6=ds_Test1cubicAFB.Debug6(sample:end);
    ds_Test1cubicAFB.time0=ds_Test1cubicAFB.time0(1:length(ds_Test1cubicAFB.Debug1));
    sample=sample_d-min_sample;
    ds_Test1noAFB.Debug1=ds_Test1noAFB.Debug1(sample:end);
    ds_Test1noAFB.Debug2=ds_Test1noAFB.Debug2(sample:end);
    ds_Test1noAFB.Debug3=ds_Test1noAFB.Debug3(sample:end);
    ds_Test1noAFB.Debug4=ds_Test1noAFB.Debug4(sample:end);
    ds_Test1noAFB.Debug5=ds_Test1noAFB.Debug5(sample:end);
    ds_Test1noAFB.Debug6=ds_Test1noAFB.Debug6(sample:end);
    ds_Test1noAFB.time0=ds_Test1noAFB.time0(1:length(ds_Test1noAFB.Debug1));
elseif sample_b==min_sample
    sample=sample_a-min_sample;
    ds_Test1AFB.Debug1=ds_Test1AFB.Debug1(sample:end);
    ds_Test1AFB.Debug2=ds_Test1AFB.Debug2(sample:end);
    ds_Test1AFB.Debug3=ds_Test1AFB.Debug3(sample:end);
    ds_Test1AFB.Debug4=ds_Test1AFB.Debug4(sample:end);
    ds_Test1AFB.Debug5=ds_Test1AFB.Debug5(sample:end);
    ds_Test1AFB.Debug6=ds_Test1AFB.Debug6(sample:end);
    ds_Test1AFB.time0=ds_Test1AFB.time0(1:length(ds_Test1AFB.Debug1));
    sample=sample_c-min_sample;
    ds_Test1cubicAFB.Debug1=ds_Test1cubicAFB.Debug1(sample:end);
    ds_Test1cubicAFB.Debug2=ds_Test1cubicAFB.Debug2(sample:end);
    ds_Test1cubicAFB.Debug3=ds_Test1cubicAFB.Debug3(sample:end);
    ds_Test1cubicAFB.Debug4=ds_Test1cubicAFB.Debug4(sample:end);
    ds_Test1cubicAFB.Debug5=ds_Test1cubicAFB.Debug5(sample:end);
    ds_Test1cubicAFB.Debug6=ds_Test1cubicAFB.Debug6(sample:end);
    ds_Test1cubicAFB.time0=ds_Test1cubicAFB.time0(1:length(ds_Test1cubicAFB.Debug1));
    sample=sample_d-min_sample;
    ds_Test1noAFB.Debug1=ds_Test1noAFB.Debug1(sample:end);
    ds_Test1noAFB.Debug2=ds_Test1noAFB.Debug2(sample:end);
    ds_Test1noAFB.Debug3=ds_Test1noAFB.Debug3(sample:end);
    ds_Test1noAFB.Debug4=ds_Test1noAFB.Debug4(sample:end);
    ds_Test1noAFB.Debug5=ds_Test1noAFB.Debug5(sample:end);
    ds_Test1noAFB.Debug6=ds_Test1noAFB.Debug6(sample:end);
    ds_Test1noAFB.time0=ds_Test1noAFB.time0(1:length(ds_Test1noAFB.Debug1));
elseif sample_c==min_sample
    sample=sample_a-min_sample;
    ds_Test1AFB.Debug1=ds_Test1AFB.Debug1(sample:end);
    ds_Test1AFB.Debug2=ds_Test1AFB.Debug2(sample:end);
    ds_Test1AFB.Debug3=ds_Test1AFB.Debug3(sample:end);
    ds_Test1AFB.Debug4=ds_Test1AFB.Debug4(sample:end);
    ds_Test1AFB.Debug5=ds_Test1AFB.Debug5(sample:end);
    ds_Test1AFB.Debug6=ds_Test1AFB.Debug6(sample:end);
    ds_Test1AFB.time0=ds_Test1AFB.time0(1:length(ds_Test1AFB.Debug1));
    sample=sample_b-min_sample;
    ds_Test1cubic.Debug1=ds_Test1cubic.Debug1(sample:end);
    ds_Test1cubic.Debug2=ds_Test1cubic.Debug2(sample:end);
    ds_Test1cubic.Debug3=ds_Test1cubic.Debug3(sample:end);
    ds_Test1cubic.Debug4=ds_Test1cubic.Debug4(sample:end);
    ds_Test1cubic.Debug5=ds_Test1cubic.Debug5(sample:end);
    ds_Test1cubic.Debug6=ds_Test1cubic.Debug6(sample:end);
    ds_Test1cubic.time0=ds_Test1cubic.time0(1:length(ds_Test1cubic.Debug1));
    sample=sample_d-min_sample;
    ds_Test1noAFB.Debug1=ds_Test1noAFB.Debug1(sample:end);
    ds_Test1noAFB.Debug2=ds_Test1noAFB.Debug2(sample:end);
    ds_Test1noAFB.Debug3=ds_Test1noAFB.Debug3(sample:end);
    ds_Test1noAFB.Debug4=ds_Test1noAFB.Debug4(sample:end);
    ds_Test1noAFB.Debug5=ds_Test1noAFB.Debug5(sample:end);
    ds_Test1noAFB.Debug6=ds_Test1noAFB.Debug6(sample:end);
    ds_Test1noAFB.time0=ds_Test1noAFB.time0(1:length(ds_Test1noAFB.Debug1));
else
    sample=sample_a-min_sample;
    ds_Test1AFB.Debug1=ds_Test1AFB.Debug1(sample:end);
    ds_Test1AFB.Debug2=ds_Test1AFB.Debug2(sample:end);
    ds_Test1AFB.Debug3=ds_Test1AFB.Debug3(sample:end);
    ds_Test1AFB.Debug4=ds_Test1AFB.Debug4(sample:end);
    ds_Test1AFB.Debug5=ds_Test1AFB.Debug5(sample:end);
    ds_Test1AFB.Debug6=ds_Test1AFB.Debug6(sample:end);
    ds_Test1AFB.time0=ds_Test1AFB.time0(1:length(ds_Test1AFB.Debug1));
    sample=sample_b-min_sample;
    ds_Test1cubic.Debug1=ds_Test1cubic.Debug1(sample:end);
    ds_Test1cubic.Debug2=ds_Test1cubic.Debug2(sample:end);
    ds_Test1cubic.Debug3=ds_Test1cubic.Debug3(sample:end);
    ds_Test1cubic.Debug4=ds_Test1cubic.Debug4(sample:end);
    ds_Test1cubic.Debug5=ds_Test1cubic.Debug5(sample:end);
    ds_Test1cubic.Debug6=ds_Test1cubic.Debug6(sample:end);
    ds_Test1cubic.time0=ds_Test1cubic.time0(1:length(ds_Test1cubic.Debug1));
    sample=sample_c-min_sample;
    ds_Test1cubicAFB.Debug1=ds_Test1cubicAFB.Debug1(sample:end);
    ds_Test1cubicAFB.Debug2=ds_Test1cubicAFB.Debug2(sample:end);
    ds_Test1cubicAFB.Debug3=ds_Test1cubicAFB.Debug3(sample:end);
    ds_Test1cubicAFB.Debug4=ds_Test1cubicAFB.Debug4(sample:end);
    ds_Test1cubicAFB.Debug5=ds_Test1cubicAFB.Debug5(sample:end);
    ds_Test1cubicAFB.Debug6=ds_Test1cubicAFB.Debug6(sample:end);
    ds_Test1cubicAFB.time0=ds_Test1cubicAFB.time0(1:length(ds_Test1cubicAFB.Debug1));
end


%Plot debug values
figure
subplot(3,1,1)
plot(ds_Test1AFB.time0,-ds_Test1AFB.Debug1)
hold on
plot(ds_Test1cubic.time0,-ds_Test1cubic.Debug1,'g')
hold on
plot(ds_Test1cubicAFB.time0,-ds_Test1cubicAFB.Debug1,'k')
hold on
plot(ds_Test1noAFB.time0,-ds_Test1noAFB.Debug1,'r')
xlim([ds_Test1AFB.time0(1) ds_Test1AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
legend('AFF','Cubic','Cubic + AFF','PID','Location','SouthEast')

subplot(3,1,2)
plot(ds_Test1AFB.time0,-ds_Test1AFB.Debug2)
hold on
plot(ds_Test1cubic.time0,-ds_Test1cubic.Debug2,'g')
hold on
plot(ds_Test1cubicAFB.time0,-ds_Test1cubicAFB.Debug2,'k')
hold on
plot(ds_Test1noAFB.time0,-ds_Test1noAFB.Debug2,'r')
xlim([ds_Test1AFB.time0(1) ds_Test1AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(ds_Test1AFB.time0,-ds_Test1AFB.Debug3)
hold on
plot(ds_Test1cubic.time0,-ds_Test1cubic.Debug3,'g')
hold on
plot(ds_Test1cubicAFB.time0,-ds_Test1cubicAFB.Debug3,'k')
hold on
plot(ds_Test1noAFB.time0,-ds_Test1noAFB.Debug3,'r')
xlim([ds_Test1AFB.time0(1) ds_Test1AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures/MTcase/Test1_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dbmp MTCase1eta.bmp -r300

figure
subplot(3,1,1)
plot(ds_Test1AFB.time0,-ds_Test1AFB.Debug4)
hold on
plot(ds_Test1cubic.time0,-ds_Test1cubic.Debug4,'g')
hold on
plot(ds_Test1cubicAFB.time0,-ds_Test1cubicAFB.Debug4,'k')
hold on
plot(ds_Test1noAFB.time0,-ds_Test1noAFB.Debug4,'r')
xlim([ds_Test1AFB.time0(1) ds_Test1noAFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
legend('AFF','Cubic','Cubic + AFF','PID','Location','NorthEast')

subplot(3,1,2)
plot(ds_Test1AFB.time0,-ds_Test1AFB.Debug5)
hold on
plot(ds_Test1cubic.time0,-ds_Test1cubic.Debug5,'g')
hold on
plot(ds_Test1cubicAFB.time0,-ds_Test1cubicAFB.Debug5,'k')
hold on
plot(ds_Test1noAFB.time0,-ds_Test1noAFB.Debug5,'r')
xlim([ds_Test1AFB.time0(1) ds_Test1noAFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(ds_Test1AFB.time0,-ds_Test1AFB.Debug6)
hold on
plot(ds_Test1cubic.time0,-ds_Test1cubic.Debug6,'g')
hold on
plot(ds_Test1cubicAFB.time0,-ds_Test1cubicAFB.Debug6,'k')
hold on
plot(ds_Test1noAFB.time0,-ds_Test1noAFB.Debug6,'r')
xlim([ds_Test1AFB.time0(1) ds_Test1noAFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
saveas(gcf, 'figures/MTcase/Test1_thrust', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dbmp MTCase1tau.bmp -r300

%% Case 2
% Disturbance force: F_ice=4e5, displacement=[40 4], AoI=10 degrees
% Yields bias term in MT simulator [40.1 7 3.5] (ton), where the moment 
% has been scaled to ton by dividing by the mean lever arm=34.75 meter.

%Choose logfile, remove decimal commas and convert to dataset
%With AFB
Logfile = 'Test2AFB.csv';
csvfix
[ds_Test2AFB] = create_log_dataset();
save('LogData\Test2AFB.mat','ds_Test2AFB');
%With Cubic
Logfile = 'Test2cubic.csv';
csvfix
[ds_Test2cubic] = create_log_dataset();
save('LogData\Test2cubic.mat','ds_Test2cubic');
%With Cubic+AFB
Logfile = 'Test2cubicAFB.csv';
csvfix
[ds_Test2cubicAFB] = create_log_dataset();
save('LogData\Test2cubicAFB.mat','ds_Test2cubicAFB');
%Without AFB
Logfile = 'Test2noAFB.csv';
csvfix
[ds_Test2noAFB] = create_log_dataset();
save('LogData\Test2noAFB.mat','ds_Test2noAFB');


%Rotate to NED-frame, first dataset
for i=1:length(ds_Test2AFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test2AFB.Debug3(i))*...
      [ds_Test2AFB.Debug1(i),ds_Test2AFB.Debug2(i),ds_Test2AFB.Debug3(i)]';
    ds_Test2AFB.Debug1(i)=a(1);
    ds_Test2AFB.Debug2(i)=a(2);
    ds_Test2AFB.Debug3(i)=a(3);
end

%Rotate to NED-frame, second dataset
for i=1:length(ds_Test2noAFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test2noAFB.Debug3(i))*...
      [ds_Test2noAFB.Debug1(i),ds_Test2noAFB.Debug2(i),ds_Test2noAFB.Debug3(i)]';
    ds_Test2noAFB.Debug1(i)=a(1);
    ds_Test2noAFB.Debug2(i)=a(2);
    ds_Test2noAFB.Debug3(i)=a(3);
end

%Rotate to NED-frame, third dataset
for i=1:length(ds_Test2cubic.time0)
    a=Rzyx(0,0,pi/180*ds_Test2cubic.Debug3(i))*...
      [ds_Test2cubic.Debug1(i),ds_Test2cubic.Debug2(i),ds_Test2cubic.Debug3(i)]';
    ds_Test2cubic.Debug1(i)=a(1);
    ds_Test2cubic.Debug2(i)=a(2);
    ds_Test2cubic.Debug3(i)=a(3);
end

%Rotate to NED-frame, fourth dataset
for i=1:length(ds_Test2cubicAFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test2cubicAFB.Debug3(i))*...
      [ds_Test2cubicAFB.Debug1(i),ds_Test2cubicAFB.Debug2(i),ds_Test2cubicAFB.Debug3(i)]';
    ds_Test2cubicAFB.Debug1(i)=a(1);
    ds_Test2cubicAFB.Debug2(i)=a(2);
    ds_Test2cubicAFB.Debug3(i)=a(3);
end

%Scale from ton to N and Nm, first dataset
Momentarm=34.75;
Newton_per_ton=9806.65;
ds_Test2AFB.Debug4=Newton_per_ton.*ds_Test2AFB.Debug4;
ds_Test2AFB.Debug5=Newton_per_ton.*ds_Test2AFB.Debug5;
ds_Test2AFB.Debug6=Newton_per_ton*Momentarm.*ds_Test2AFB.Debug6;

%Scale from ton to N and Nm, first dataset
ds_Test2noAFB.Debug4=Newton_per_ton.*ds_Test2noAFB.Debug4;
ds_Test2noAFB.Debug5=Newton_per_ton.*ds_Test2noAFB.Debug5;
ds_Test2noAFB.Debug6=Newton_per_ton*Momentarm.*ds_Test2noAFB.Debug6;

%Scale from ton to N and Nm, third dataset
ds_Test2cubic.Debug4=Newton_per_ton.*ds_Test2cubic.Debug4;
ds_Test2cubic.Debug5=Newton_per_ton.*ds_Test2cubic.Debug5;
ds_Test2cubic.Debug6=Newton_per_ton*Momentarm.*ds_Test2cubic.Debug6;

%Scale from ton to N and Nm, fourth dataset
ds_Test2cubicAFB.Debug4=Newton_per_ton.*ds_Test2cubicAFB.Debug4;
ds_Test2cubicAFB.Debug5=Newton_per_ton.*ds_Test2cubicAFB.Debug5;
ds_Test2cubicAFB.Debug6=Newton_per_ton*Momentarm.*ds_Test2cubicAFB.Debug6;

%Low-pass filter noisy signal
[ds_Test2noAFB] = lowpass(ds_Test2noAFB);
[ds_Test2AFB] = lowpass(ds_Test2AFB); 
[ds_Test2cubicAFB] = lowpass(ds_Test2cubicAFB);
[ds_Test2cubic] = lowpass(ds_Test2cubic);

%Sync datasets
test_set_a=ds_Test2AFB.Debug4;
sample_a=0;
for i=1:length(test_set_a)
    if abs(test_set_a(i))>100
        sample_a=i;
        break;
    end
end
test_set_b=ds_Test2cubic.Debug4;
sample_b=0;
for i=1:length(test_set_b)
    if abs(test_set_b(i))>100
        sample_b=i;
        break;
    end
end
test_set_c=ds_Test2cubicAFB.Debug4;
sample_c=0;
for i=1:length(test_set_c)
    if abs(test_set_c(i))>100
        sample_c=i;
        break;
    end
end
test_set_d=ds_Test2noAFB.Debug4;
sample_d=0;
for i=1:length(test_set_d)
    if abs(test_set_d(i))>100
        sample_d=i;
        break;
    end
end

min_sample=min([sample_a, sample_b, sample_c, sample_d]);

if sample_a==min_sample
    sample=sample_b-min_sample;
    ds_Test2cubic.Debug1=ds_Test2cubic.Debug1(sample:end);
    ds_Test2cubic.Debug2=ds_Test2cubic.Debug2(sample:end);
    ds_Test2cubic.Debug3=ds_Test2cubic.Debug3(sample:end);
    ds_Test2cubic.Debug4=ds_Test2cubic.Debug4(sample:end);
    ds_Test2cubic.Debug5=ds_Test2cubic.Debug5(sample:end);
    ds_Test2cubic.Debug6=ds_Test2cubic.Debug6(sample:end);
    ds_Test2cubic.time0=ds_Test2cubic.time0(1:length(ds_Test2cubic.Debug1));
    sample=sample_c-min_sample;
    ds_Test2cubicAFB.Debug1=ds_Test2cubicAFB.Debug1(sample:end);
    ds_Test2cubicAFB.Debug2=ds_Test2cubicAFB.Debug2(sample:end);
    ds_Test2cubicAFB.Debug3=ds_Test2cubicAFB.Debug3(sample:end);
    ds_Test2cubicAFB.Debug4=ds_Test2cubicAFB.Debug4(sample:end);
    ds_Test2cubicAFB.Debug5=ds_Test2cubicAFB.Debug5(sample:end);
    ds_Test2cubicAFB.Debug6=ds_Test2cubicAFB.Debug6(sample:end);
    ds_Test2cubicAFB.time0=ds_Test2cubicAFB.time0(1:length(ds_Test2cubicAFB.Debug1));
    sample=sample_d-min_sample;
    ds_Test2noAFB.Debug1=ds_Test2noAFB.Debug1(sample:end);
    ds_Test2noAFB.Debug2=ds_Test2noAFB.Debug2(sample:end);
    ds_Test2noAFB.Debug3=ds_Test2noAFB.Debug3(sample:end);
    ds_Test2noAFB.Debug4=ds_Test2noAFB.Debug4(sample:end);
    ds_Test2noAFB.Debug5=ds_Test2noAFB.Debug5(sample:end);
    ds_Test2noAFB.Debug6=ds_Test2noAFB.Debug6(sample:end);
    ds_Test2noAFB.time0=ds_Test2noAFB.time0(1:length(ds_Test2noAFB.Debug1));
elseif sample_b==min_sample
    sample=sample_a-min_sample;
    ds_Test2AFB.Debug1=ds_Test2AFB.Debug1(sample:end);
    ds_Test2AFB.Debug2=ds_Test2AFB.Debug2(sample:end);
    ds_Test2AFB.Debug3=ds_Test2AFB.Debug3(sample:end);
    ds_Test2AFB.Debug4=ds_Test2AFB.Debug4(sample:end);
    ds_Test2AFB.Debug5=ds_Test2AFB.Debug5(sample:end);
    ds_Test2AFB.Debug6=ds_Test2AFB.Debug6(sample:end);
    ds_Test2AFB.time0=ds_Test2AFB.time0(1:length(ds_Test2AFB.Debug1));
    sample=sample_c-min_sample;
    ds_Test2cubicAFB.Debug1=ds_Test2cubicAFB.Debug1(sample:end);
    ds_Test2cubicAFB.Debug2=ds_Test2cubicAFB.Debug2(sample:end);
    ds_Test2cubicAFB.Debug3=ds_Test2cubicAFB.Debug3(sample:end);
    ds_Test2cubicAFB.Debug4=ds_Test2cubicAFB.Debug4(sample:end);
    ds_Test2cubicAFB.Debug5=ds_Test2cubicAFB.Debug5(sample:end);
    ds_Test2cubicAFB.Debug6=ds_Test2cubicAFB.Debug6(sample:end);
    ds_Test2cubicAFB.time0=ds_Test2cubicAFB.time0(1:length(ds_Test2cubicAFB.Debug1));
    sample=sample_d-min_sample;
    ds_Test2noAFB.Debug1=ds_Test2noAFB.Debug1(sample:end);
    ds_Test2noAFB.Debug2=ds_Test2noAFB.Debug2(sample:end);
    ds_Test2noAFB.Debug3=ds_Test2noAFB.Debug3(sample:end);
    ds_Test2noAFB.Debug4=ds_Test2noAFB.Debug4(sample:end);
    ds_Test2noAFB.Debug5=ds_Test2noAFB.Debug5(sample:end);
    ds_Test2noAFB.Debug6=ds_Test2noAFB.Debug6(sample:end);
    ds_Test2noAFB.time0=ds_Test2noAFB.time0(1:length(ds_Test2noAFB.Debug1));
elseif sample_c==min_sample
    sample=sample_a-min_sample;
    ds_Test2AFB.Debug1=ds_Test2AFB.Debug1(sample:end);
    ds_Test2AFB.Debug2=ds_Test2AFB.Debug2(sample:end);
    ds_Test2AFB.Debug3=ds_Test2AFB.Debug3(sample:end);
    ds_Test2AFB.Debug4=ds_Test2AFB.Debug4(sample:end);
    ds_Test2AFB.Debug5=ds_Test2AFB.Debug5(sample:end);
    ds_Test2AFB.Debug6=ds_Test2AFB.Debug6(sample:end);
    ds_Test2AFB.time0=ds_Test2AFB.time0(1:length(ds_Test2AFB.Debug1));
    sample=sample_b-min_sample;
    ds_Test2cubic.Debug1=ds_Test2cubic.Debug1(sample:end);
    ds_Test2cubic.Debug2=ds_Test2cubic.Debug2(sample:end);
    ds_Test2cubic.Debug3=ds_Test2cubic.Debug3(sample:end);
    ds_Test2cubic.Debug4=ds_Test2cubic.Debug4(sample:end);
    ds_Test2cubic.Debug5=ds_Test2cubic.Debug5(sample:end);
    ds_Test2cubic.Debug6=ds_Test2cubic.Debug6(sample:end);
    ds_Test2cubic.time0=ds_Test2cubic.time0(1:length(ds_Test2cubic.Debug1));
    sample=sample_d-min_sample;
    ds_Test2noAFB.Debug1=ds_Test2noAFB.Debug1(sample:end);
    ds_Test2noAFB.Debug2=ds_Test2noAFB.Debug2(sample:end);
    ds_Test2noAFB.Debug3=ds_Test2noAFB.Debug3(sample:end);
    ds_Test2noAFB.Debug4=ds_Test2noAFB.Debug4(sample:end);
    ds_Test2noAFB.Debug5=ds_Test2noAFB.Debug5(sample:end);
    ds_Test2noAFB.Debug6=ds_Test2noAFB.Debug6(sample:end);
    ds_Test2noAFB.time0=ds_Test2noAFB.time0(1:length(ds_Test2noAFB.Debug1));
else
    sample=sample_a-min_sample;
    ds_Test2AFB.Debug1=ds_Test2AFB.Debug1(sample:end);
    ds_Test2AFB.Debug2=ds_Test2AFB.Debug2(sample:end);
    ds_Test2AFB.Debug3=ds_Test2AFB.Debug3(sample:end);
    ds_Test2AFB.Debug4=ds_Test2AFB.Debug4(sample:end);
    ds_Test2AFB.Debug5=ds_Test2AFB.Debug5(sample:end);
    ds_Test2AFB.Debug6=ds_Test2AFB.Debug6(sample:end);
    ds_Test2AFB.time0=ds_Test2AFB.time0(1:length(ds_Test2AFB.Debug1));
    sample=sample_b-min_sample;
    ds_Test2cubic.Debug1=ds_Test2cubic.Debug1(sample:end);
    ds_Test2cubic.Debug2=ds_Test2cubic.Debug2(sample:end);
    ds_Test2cubic.Debug3=ds_Test2cubic.Debug3(sample:end);
    ds_Test2cubic.Debug4=ds_Test2cubic.Debug4(sample:end);
    ds_Test2cubic.Debug5=ds_Test2cubic.Debug5(sample:end);
    ds_Test2cubic.Debug6=ds_Test2cubic.Debug6(sample:end);
    ds_Test2cubic.time0=ds_Test2cubic.time0(1:length(ds_Test2cubic.Debug1));
    sample=sample_c-min_sample;
    ds_Test2cubicAFB.Debug1=ds_Test2cubicAFB.Debug1(sample:end);
    ds_Test2cubicAFB.Debug2=ds_Test2cubicAFB.Debug2(sample:end);
    ds_Test2cubicAFB.Debug3=ds_Test2cubicAFB.Debug3(sample:end);
    ds_Test2cubicAFB.Debug4=ds_Test2cubicAFB.Debug4(sample:end);
    ds_Test2cubicAFB.Debug5=ds_Test2cubicAFB.Debug5(sample:end);
    ds_Test2cubicAFB.Debug6=ds_Test2cubicAFB.Debug6(sample:end);
    ds_Test2cubicAFB.time0=ds_Test2cubicAFB.time0(1:length(ds_Test2cubicAFB.Debug1));
end



%Plot debug values
figure
subplot(3,1,1)
plot(ds_Test2AFB.time0,ds_Test2AFB.Debug1)
hold on
plot(ds_Test2cubic.time0,ds_Test2cubic.Debug1,'g')
hold on
plot(ds_Test2cubicAFB.time0,ds_Test2cubicAFB.Debug1,'k')
hold on
plot(ds_Test2noAFB.time0,ds_Test2noAFB.Debug1,'r')
xlim([ds_Test2AFB.time0(1) ds_Test2AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
legend('AFF','Cubic','Cubic + AFF','PID','Location','SouthEast')

subplot(3,1,2)
plot(ds_Test2AFB.time0,ds_Test2AFB.Debug2)
hold on
plot(ds_Test2cubic.time0,ds_Test2cubic.Debug2,'g')
hold on
plot(ds_Test2cubicAFB.time0,ds_Test2cubicAFB.Debug2,'k')
hold on
plot(ds_Test2noAFB.time0,ds_Test2noAFB.Debug2,'r')
xlim([ds_Test2AFB.time0(1) ds_Test2AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

subplot(3,1,3)
plot(ds_Test2AFB.time0,ds_Test2AFB.Debug3)
hold on
plot(ds_Test2cubic.time0,ds_Test2cubic.Debug3,'g')
hold on
plot(ds_Test2cubicAFB.time0,ds_Test2cubicAFB.Debug3,'k')
hold on
plot(ds_Test2noAFB.time0,ds_Test2noAFB.Debug3,'r')
xlim([ds_Test2AFB.time0(1) ds_Test2AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in yaw (deg)')
saveas(gcf, 'figures/MTcase/Test2_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dbmp MTCase2eta.bmp -r300


figure
subplot(3,1,1)
plot(ds_Test2AFB.time0,ds_Test2AFB.Debug4)
hold on
plot(ds_Test2cubic.time0,ds_Test2cubic.Debug4,'g')
hold on
plot(ds_Test2cubicAFB.time0,ds_Test2cubicAFB.Debug4,'k')
hold on
plot(ds_Test2noAFB.time0,ds_Test2noAFB.Debug4,'r')
xlim([ds_Test2AFB.time0(1) ds_Test2AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
legend('AFF','Cubic','Cubic + AFF','PID','Location','NorthEast')

subplot(3,1,2)
plot(ds_Test2AFB.time0,ds_Test2AFB.Debug5)
hold on
plot(ds_Test2cubic.time0,ds_Test2cubic.Debug5,'g')
hold on
plot(ds_Test2cubicAFB.time0,ds_Test2cubicAFB.Debug5,'k')
hold on
plot(ds_Test2noAFB.time0,ds_Test2noAFB.Debug5,'r')
xlim([ds_Test2AFB.time0(1) ds_Test2AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')

subplot(3,1,3)
plot(ds_Test2AFB.time0,ds_Test2AFB.Debug6)
hold on
plot(ds_Test2cubic.time0,ds_Test2cubic.Debug6,'g')
hold on
plot(ds_Test2cubicAFB.time0,ds_Test2cubicAFB.Debug6,'k')
hold on
plot(ds_Test2noAFB.time0,ds_Test2noAFB.Debug6,'r')
xlim([ds_Test2noAFB.time0(1) ds_Test2noAFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)')    
saveas(gcf, 'figures/MTcase/Test2_thrust', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dbmp MTCase2tau.bmp -r300
%% Case 3
% Position reference = [5 5]

%Choose logfile, remove decimal commas and convert to dataset
%With AFB
Logfile = 'Test3AFB.csv';
csvfix
[ds_Test3AFB] = create_log_dataset();
save('LogData\Test3AFB.mat','ds_Test3AFB');
%With Cubic
Logfile = 'Test3cubic.csv';
csvfix
[ds_Test3cubic] = create_log_dataset();
save('LogData\Test3cubic.mat','ds_Test3cubic');
%With Cubic+AFB
Logfile = 'Test3cubicAFB.csv';
csvfix
[ds_Test3cubicAFB] = create_log_dataset();
save('LogData\Test3cubicAFB.mat','ds_Test3cubicAFB');
%Without AFB
Logfile = 'Test3noAFB.csv';
csvfix
[ds_Test3noAFB] = create_log_dataset();
save('LogData\Test3noAFB.mat','ds_Test3noAFB');


%Rotate to NED-frame, first dataset
for i=1:length(ds_Test3AFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test3AFB.Debug3(i))*...
      [ds_Test3AFB.Debug1(i),ds_Test3AFB.Debug2(i),ds_Test3AFB.Debug3(i)]';
    ds_Test3AFB.Debug1(i)=a(1);
    ds_Test3AFB.Debug2(i)=a(2);
    ds_Test3AFB.Debug3(i)=a(3);
end

%Rotate to NED-frame, second dataset
for i=1:length(ds_Test3cubic.time0)
    a=Rzyx(0,0,pi/180*ds_Test3cubic.Debug3(i))*...
      [ds_Test3cubic.Debug1(i),ds_Test3cubic.Debug2(i),ds_Test3cubic.Debug3(i)]';
    ds_Test3cubic.Debug1(i)=a(1);
    ds_Test3cubic.Debug2(i)=a(2);
    ds_Test3cubic.Debug3(i)=a(3);
end


%Rotate to NED-frame, third dataset
for i=1:length(ds_Test3cubicAFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test3cubicAFB.Debug3(i))*...
      [ds_Test3cubicAFB.Debug1(i),ds_Test3cubicAFB.Debug2(i),ds_Test3cubicAFB.Debug3(i)]';
    ds_Test3cubicAFB.Debug1(i)=a(1);
    ds_Test3cubicAFB.Debug2(i)=a(2);
    ds_Test3cubicAFB.Debug3(i)=a(3);
end

%Rotate to NED-frame, fourth dataset

for i=1:length(ds_Test3noAFB.time0)
    a=Rzyx(0,0,pi/180*ds_Test3noAFB.Debug3(i))*...
      [ds_Test3noAFB.Debug1(i),ds_Test3noAFB.Debug2(i),ds_Test3noAFB.Debug3(i)]';
    ds_Test3noAFB.Debug1(i)=a(1);
    ds_Test3noAFB.Debug2(i)=a(2);
    ds_Test3noAFB.Debug3(i)=a(3);
end

%Scale from ton to N and Nm, first dataset
Momentarm=34.75;
Newton_per_ton=9806.65;
ds_Test3AFB.Debug4=Newton_per_ton.*ds_Test3AFB.Debug4;
ds_Test3AFB.Debug5=Newton_per_ton.*ds_Test3AFB.Debug5;
ds_Test3AFB.Debug6=Newton_per_ton*Momentarm.*ds_Test3AFB.Debug6;

%Scale from ton to N and Nm, second dataset
ds_Test3noAFB.Debug4=Newton_per_ton.*ds_Test3noAFB.Debug4;
ds_Test3noAFB.Debug5=Newton_per_ton.*ds_Test3noAFB.Debug5;
ds_Test3noAFB.Debug6=Newton_per_ton*Momentarm.*ds_Test3noAFB.Debug6;

%Scale from ton to N and Nm, third dataset
ds_Test3cubic.Debug4=Newton_per_ton.*ds_Test3cubic.Debug4;
ds_Test3cubic.Debug5=Newton_per_ton.*ds_Test3cubic.Debug5;
ds_Test3cubic.Debug6=Newton_per_ton*Momentarm.*ds_Test3cubic.Debug6;

%Scale from ton to N and Nm, fourth dataset
ds_Test3cubicAFB.Debug4=Newton_per_ton.*ds_Test3cubicAFB.Debug4;
ds_Test3cubicAFB.Debug5=Newton_per_ton.*ds_Test3cubicAFB.Debug5;
ds_Test3cubicAFB.Debug6=Newton_per_ton*Momentarm.*ds_Test3cubicAFB.Debug6;

%Low-pass filter noisy signal
[ds_Test3noAFB] = lowpass(ds_Test3noAFB);
[ds_Test3AFB] = lowpass(ds_Test3AFB);
[ds_Test3cubicAFB] = lowpass(ds_Test3cubicAFB);
[ds_Test3cubic] = lowpass(ds_Test3cubic);

%Sync datasets
test_set_a=ds_Test3AFB.Debug4;
sample_a=0;
for i=1:length(test_set_a)
    if abs(test_set_a(i))>100
        sample_a=i;
        break;
    end
end
test_set_b=ds_Test3cubic.Debug4;
sample_b=0;
for i=1:length(test_set_b)
    if abs(test_set_b(i))>100
        sample_b=i;
        break;
    end
end
test_set_c=ds_Test3cubicAFB.Debug4;
sample_c=0;
for i=1:length(test_set_c)
    if abs(test_set_c(i))>100
        sample_c=i;
        break;
    end
end
test_set_d=ds_Test3noAFB.Debug4;
sample_d=0;
for i=1:length(test_set_d)
    if abs(test_set_d(i))>100
        sample_d=i;
        break;
    end
end

min_sample=min([sample_a, sample_b, sample_c, sample_d]);

if sample_a==min_sample
    sample=sample_b-min_sample;
    ds_Test3cubic.Debug1=ds_Test3cubic.Debug1(sample:end);
    ds_Test3cubic.Debug2=ds_Test3cubic.Debug2(sample:end);
    ds_Test3cubic.Debug3=ds_Test3cubic.Debug3(sample:end);
    ds_Test3cubic.Debug4=ds_Test3cubic.Debug4(sample:end);
    ds_Test3cubic.Debug5=ds_Test3cubic.Debug5(sample:end);
    ds_Test3cubic.Debug6=ds_Test3cubic.Debug6(sample:end);
    ds_Test3cubic.time0=ds_Test3cubic.time0(1:length(ds_Test3cubic.Debug1));
    sample=sample_c-min_sample;
    ds_Test3cubicAFB.Debug1=ds_Test3cubicAFB.Debug1(sample:end);
    ds_Test3cubicAFB.Debug2=ds_Test3cubicAFB.Debug2(sample:end);
    ds_Test3cubicAFB.Debug3=ds_Test3cubicAFB.Debug3(sample:end);
    ds_Test3cubicAFB.Debug4=ds_Test3cubicAFB.Debug4(sample:end);
    ds_Test3cubicAFB.Debug5=ds_Test3cubicAFB.Debug5(sample:end);
    ds_Test3cubicAFB.Debug6=ds_Test3cubicAFB.Debug6(sample:end);
    ds_Test3cubicAFB.time0=ds_Test3cubicAFB.time0(1:length(ds_Test3cubicAFB.Debug1));
    sample=sample_d-min_sample;
    ds_Test3noAFB.Debug1=ds_Test3noAFB.Debug1(sample:end);
    ds_Test3noAFB.Debug2=ds_Test3noAFB.Debug2(sample:end);
    ds_Test3noAFB.Debug3=ds_Test3noAFB.Debug3(sample:end);
    ds_Test3noAFB.Debug4=ds_Test3noAFB.Debug4(sample:end);
    ds_Test3noAFB.Debug5=ds_Test3noAFB.Debug5(sample:end);
    ds_Test3noAFB.Debug6=ds_Test3noAFB.Debug6(sample:end);
    ds_Test3noAFB.time0=ds_Test3noAFB.time0(1:length(ds_Test3noAFB.Debug1));
elseif sample_b==min_sample
    sample=sample_a-min_sample;
    ds_Test3AFB.Debug1=ds_Test3AFB.Debug1(sample:end);
    ds_Test3AFB.Debug2=ds_Test3AFB.Debug2(sample:end);
    ds_Test3AFB.Debug3=ds_Test3AFB.Debug3(sample:end);
    ds_Test3AFB.Debug4=ds_Test3AFB.Debug4(sample:end);
    ds_Test3AFB.Debug5=ds_Test3AFB.Debug5(sample:end);
    ds_Test3AFB.Debug6=ds_Test3AFB.Debug6(sample:end);
    ds_Test3AFB.time0=ds_Test3AFB.time0(1:length(ds_Test3AFB.Debug1));
    sample=sample_c-min_sample;
    ds_Test3cubicAFB.Debug1=ds_Test3cubicAFB.Debug1(sample:end);
    ds_Test3cubicAFB.Debug2=ds_Test3cubicAFB.Debug2(sample:end);
    ds_Test3cubicAFB.Debug3=ds_Test3cubicAFB.Debug3(sample:end);
    ds_Test3cubicAFB.Debug4=ds_Test3cubicAFB.Debug4(sample:end);
    ds_Test3cubicAFB.Debug5=ds_Test3cubicAFB.Debug5(sample:end);
    ds_Test3cubicAFB.Debug6=ds_Test3cubicAFB.Debug6(sample:end);
    ds_Test3cubicAFB.time0=ds_Test3cubicAFB.time0(1:length(ds_Test3cubicAFB.Debug1));
    sample=sample_d-min_sample;
    ds_Test3noAFB.Debug1=ds_Test3noAFB.Debug1(sample:end);
    ds_Test3noAFB.Debug2=ds_Test3noAFB.Debug2(sample:end);
    ds_Test3noAFB.Debug3=ds_Test3noAFB.Debug3(sample:end);
    ds_Test3noAFB.Debug4=ds_Test3noAFB.Debug4(sample:end);
    ds_Test3noAFB.Debug5=ds_Test3noAFB.Debug5(sample:end);
    ds_Test3noAFB.Debug6=ds_Test3noAFB.Debug6(sample:end);
    ds_Test3noAFB.time0=ds_Test3noAFB.time0(1:length(ds_Test3noAFB.Debug1));
elseif sample_c==min_sample
    sample=sample_a-min_sample;
    ds_Test3AFB.Debug1=ds_Test3AFB.Debug1(sample:end);
    ds_Test3AFB.Debug2=ds_Test3AFB.Debug2(sample:end);
    ds_Test3AFB.Debug3=ds_Test3AFB.Debug3(sample:end);
    ds_Test3AFB.Debug4=ds_Test3AFB.Debug4(sample:end);
    ds_Test3AFB.Debug5=ds_Test3AFB.Debug5(sample:end);
    ds_Test3AFB.Debug6=ds_Test3AFB.Debug6(sample:end);
    ds_Test3AFB.time0=ds_Test3AFB.time0(1:length(ds_Test3AFB.Debug1));
    sample=sample_b-min_sample;
    ds_Test3cubic.Debug1=ds_Test3cubic.Debug1(sample:end);
    ds_Test3cubic.Debug2=ds_Test3cubic.Debug2(sample:end);
    ds_Test3cubic.Debug3=ds_Test3cubic.Debug3(sample:end);
    ds_Test3cubic.Debug4=ds_Test3cubic.Debug4(sample:end);
    ds_Test3cubic.Debug5=ds_Test3cubic.Debug5(sample:end);
    ds_Test3cubic.Debug6=ds_Test3cubic.Debug6(sample:end);
    ds_Test3cubic.time0=ds_Test3cubic.time0(1:length(ds_Test3cubic.Debug1));
    sample=sample_d-min_sample;
    ds_Test3noAFB.Debug1=ds_Test3noAFB.Debug1(sample:end);
    ds_Test3noAFB.Debug2=ds_Test3noAFB.Debug2(sample:end);
    ds_Test3noAFB.Debug3=ds_Test3noAFB.Debug3(sample:end);
    ds_Test3noAFB.Debug4=ds_Test3noAFB.Debug4(sample:end);
    ds_Test3noAFB.Debug5=ds_Test3noAFB.Debug5(sample:end);
    ds_Test3noAFB.Debug6=ds_Test3noAFB.Debug6(sample:end);
    ds_Test3noAFB.time0=ds_Test3noAFB.time0(1:length(ds_Test3noAFB.Debug1));
else
    sample=sample_a-min_sample;
    ds_Test3AFB.Debug1=ds_Test3AFB.Debug1(sample:end);
    ds_Test3AFB.Debug2=ds_Test3AFB.Debug2(sample:end);
    ds_Test3AFB.Debug3=ds_Test3AFB.Debug3(sample:end);
    ds_Test3AFB.Debug4=ds_Test3AFB.Debug4(sample:end);
    ds_Test3AFB.Debug5=ds_Test3AFB.Debug5(sample:end);
    ds_Test3AFB.Debug6=ds_Test3AFB.Debug6(sample:end);
    ds_Test3AFB.time0=ds_Test3AFB.time0(1:length(ds_Test3AFB.Debug1));
    sample=sample_b-min_sample;
    ds_Test3cubic.Debug1=ds_Test3cubic.Debug1(sample:end);
    ds_Test3cubic.Debug2=ds_Test3cubic.Debug2(sample:end);
    ds_Test3cubic.Debug3=ds_Test3cubic.Debug3(sample:end);
    ds_Test3cubic.Debug4=ds_Test3cubic.Debug4(sample:end);
    ds_Test3cubic.Debug5=ds_Test3cubic.Debug5(sample:end);
    ds_Test3cubic.Debug6=ds_Test3cubic.Debug6(sample:end);
    ds_Test3cubic.time0=ds_Test3cubic.time0(1:length(ds_Test3cubic.Debug1));
    sample=sample_c-min_sample;
    ds_Test3cubicAFB.Debug1=ds_Test3cubicAFB.Debug1(sample:end);
    ds_Test3cubicAFB.Debug2=ds_Test3cubicAFB.Debug2(sample:end);
    ds_Test3cubicAFB.Debug3=ds_Test3cubicAFB.Debug3(sample:end);
    ds_Test3cubicAFB.Debug4=ds_Test3cubicAFB.Debug4(sample:end);
    ds_Test3cubicAFB.Debug5=ds_Test3cubicAFB.Debug5(sample:end);
    ds_Test3cubicAFB.Debug6=ds_Test3cubicAFB.Debug6(sample:end);
    ds_Test3cubicAFB.time0=ds_Test3cubicAFB.time0(1:length(ds_Test3cubicAFB.Debug1));
end


%Plot debug values 
figure
subplot(2,1,1)
plot(ds_Test3AFB.time0,ds_Test3AFB.Debug1)
hold on
plot(ds_Test3cubic.time0,ds_Test3cubic.Debug1,'g')
hold on
plot(ds_Test3cubicAFB.time0,ds_Test3cubicAFB.Debug1,'k')
hold on
plot(ds_Test3noAFB.time0,ds_Test3noAFB.Debug1,'r')
xlim([ds_Test3AFB.time0(1) ds_Test3AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in surge (m)')
legend('AFF','Cubic','Cubic + AFF','PID','Location','SouthEast')

subplot(2,1,2)
plot(ds_Test3AFB.time0,ds_Test3AFB.Debug2)
hold on
plot(ds_Test3cubic.time0,ds_Test3cubic.Debug2,'g')
hold on
plot(ds_Test3cubicAFB.time0,ds_Test3cubicAFB.Debug2,'k')
hold on
plot(ds_Test3noAFB.time0,ds_Test3noAFB.Debug2,'r')
xlim([ds_Test3AFB.time0(1) ds_Test3AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('error in sway (m)')

saveas(gcf, 'figures/MTcase/Test3_posplot', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dbmp MTCase3eta.bmp -r300


figure
subplot(2,1,1)
plot(ds_Test3AFB.time0,ds_Test3AFB.Debug4)
hold on
plot(ds_Test3cubic.time0,ds_Test3cubic.Debug4,'g')
hold on
plot(ds_Test3cubicAFB.time0,ds_Test3cubicAFB.Debug4,'k')
hold on
plot(ds_Test3noAFB.time0,ds_Test3noAFB.Debug4,'r')
xlim([ds_Test3AFB.time0(1) ds_Test3AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_x (N)')
legend('AFF','Cubic','Cubic + AFF','PID','Location','NorthEast')

subplot(2,1,2)
plot(ds_Test3AFB.time0,ds_Test3AFB.Debug5)
hold on
plot(ds_Test3cubic.time0,ds_Test3cubic.Debug5,'g')
hold on
plot(ds_Test3cubicAFB.time0,ds_Test3cubicAFB.Debug5,'k')
hold on
plot(ds_Test3noAFB.time0,ds_Test3noAFB.Debug5,'r')
xlim([ds_Test3AFB.time0(1) ds_Test3AFB.time0(end)]);set_font
xlabel('Time (seconds)');ylabel('\tau_y (N)')
saveas(gcf, 'figures/MTcase/Test3_thrust', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dbmp MTCase3tau.bmp -r300

MT_find_ISE