%% Predictive simulation, find predictive box limits
%
% Created by: Christoffer Ofstad 20.02.2014
%
%% Init
clear
%Real Ice Force applied
F_ice=1e5; %Newton
displacement=[40 9];%meters
AoA=80; %degrees
constants.real_ice.force=pred_force(-F_ice,displacement,AoA);
constants.real_ice.timeon=400;

%% Initialize test parameters
delta=3;
dist=displacement; 
constants.pred.timeoff=constants.real_ice.timeon;
simulation_model = ('sim_prediction_report_test2'); 
sim_length=700;
init
clc
find_available_thrust

%Find error without prediction
constants.pred.force=pred_force(0,[0 0],0);
constants.pred.timeon=0;
sim(simulation_model);
[total_error_no_pred, max_no_pred] = error_sampling(eta, ISE_eta);

%Initialize limits for time
t0=.05;
tf=4;
t=t0:(tf-t0)/(delta-1):tf;

%Initialize limits for force
f0=1*F_ice;
ff=5*F_ice;
F=f0:(ff-f0)/(delta-1):ff;

%Initialize limits for heading
h0=AoA-30;
hf=AoA+30;
H=h0:(hf-h0)/(delta-1):hf;

%% Time vs Force
%Initialize error vector
error_pos=zeros(delta);
error_head=zeros(delta);
max_pos=zeros(delta);
max_head=zeros(delta);
opt_p1=[];
opt_h1=[];
max_p1=[];
max_h1=[];
count=0;
start_time=tic;
sim_number=1;
for k=1:length(H)
    for i=1:length(t)
        for j=1:length(F)
            constants.pred.force=pred_force(F(i),dist,H(k));
            constants.pred.timeon=constants.pred.timeoff-t(j);
            %Simulation
            sim_start=tic;
            sim(simulation_model);
            sim_time=toc(sim_start);
            [total_error, max_error] = error_sampling(eta, ISE_eta);
            error_pos(i,j)=total_error(4)/total_error_no_pred(4);
            error_head(i,j)=total_error(3)/total_error_no_pred(3);
            max_pos(i,j)=max_error(4)/max_no_pred(4);
            max_head(i,j)=max_error(3)/max_no_pred(3);
            count=count+1;
            clc
            string = [num2str(round(100*((count)/(length(t)*length(F)*length(H))))),'% complete'];
            string2= [secs2hms(abs(sim_time*(length(t)*length(F)*length(H))-toc(start_time))),' remaining'];
            disp(string);
            disp(string2);
        end
    end
    
    opt_p1 = find_box_limits(error_pos,t,F,H,k,opt_p1,sim_number);
    opt_h1 = find_box_limits(error_head,t,F,H,k,opt_h1,sim_number);
    max_p1 = find_box_limits(max_pos,t,F,H,k,max_p1,sim_number);
    max_h1 = find_box_limits(max_head,t,F,H,k,max_h1,sim_number);

end

figure(55)
cube(t,F,H)
    plot3(opt_h1(:,1),opt_h1(:,2),opt_h1(:,3),'r+');
    hold on
    plot3(opt_p1(:,1),opt_p1(:,2),opt_p1(:,3),'o');
hold off

figure(77)
cube(t,F,H)
    plot3(max_h1(:,1),max_h1(:,2),max_h1(:,3),'r+');
    hold on
    plot3(max_p1(:,1),max_p1(:,2),max_p1(:,3),'o');
hold off


