%% Predictive simulation, find box limits with fixed time
%
% Created by: Christoffer Ofstad 20.02.2014
%
clear
%% Initialize test and vessel parameters 
simulation_model = ('sim_prediction_report_test'); 
sim_length=700;
init
find_available_thrust

%Real Ice Force applied
F_ice=4e4; %Newton
displacement=[4 9];%meters
AoA_ice=80; %degrees
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=400;

% Initialize fixed test parameters 
delta=3;
constants.pred.timeoff=constants.real_ice.timeon;
t=2.5;

%Find error without prediction
constants.pred.force=pred_force(0,[0 0],0);
constants.pred.timeon=0;
sim(simulation_model);
[total_error_no_pred, max_no_pred] = error_sampling(eta, ISE_eta);

%Initialize limits for predicted position of impact
p0=-20;
pf=20;
p=p0:(pf-p0)/(delta-1):pf;

%Initialize limits for force
f0=1;
ff=3.5;
F_gamma=f0:(ff-f0)/(delta-1):ff;

%Initialize limits for heading
h0=AoA_ice-40;
hf=AoA_ice+40;
H=h0:(hf-h0)/(delta-1):hf;

%% Time vs Force
%Initialize error vector
error_pos=zeros(delta);
error_head=zeros(delta);
max_pos=zeros(delta);
max_head=zeros(delta);
opt_p1=[];
opt_h1=[];
max_p1=[];
max_h1=[];
opt_worse=[];
count=0;
start_time=tic;
sim_number=1;
for k=1:length(H)
    for i=1:length(p)
        for j=1:length(F_gamma)
            constants.pred.force=pred_force(F_gamma(i)*F_ice,(displacement+[p(j) 9]),H(k));
            constants.pred.timeon=constants.pred.timeoff-t;
            %Simulation
            sim_start=tic;
            sim(simulation_model);
            sim_time=toc(sim_start);
            [total_error, max_error] = error_sampling(eta, ISE_eta);
            error_pos(i,j)=total_error(4)/total_error_no_pred(4);
            error_head(i,j)=total_error(3)/total_error_no_pred(3);
            max_pos(i,j)=max_error(4)/max_no_pred(4);
            max_head(i,j)=max_error(3)/max_no_pred(3);
            count=count+1;
            clc
            string = [num2str(round(100*((count)/(length(p)*length(F_gamma)*length(H))))),'% complete'];
            string2= [secs2hms(abs(sim_time*(length(p)*length(F_gamma)*length(H))-toc(start_time))),' remaining'];
            disp(string);
            disp(string2);
        end
    end
    
    opt_p1 = find_box_limits(error_pos,p,F_gamma,H,k,opt_p1,sim_number);
    opt_h1 = find_box_limits(error_head,p,F_gamma,H,k,opt_h1,sim_number);
    max_p1 = find_box_limits(max_pos,p,F_gamma,H,k,max_p1,sim_number);
    max_h1 = find_box_limits(max_head,p,F_gamma,H,k,max_h1,sim_number);
    opt_worse= find_box_limits_worse(error_pos,error_head,p,F_gamma,H,k,opt_worse,sim_number);

end

%% Plotting

figure(55)
plot3(opt_p1(:,1),opt_p1(:,2),opt_p1(:,3),'o','LineWidth',1);
hold on
plot3(opt_h1(:,1),opt_h1(:,2),opt_h1(:,3),'r+','LineWidth',1);
hold on
% legend('position','heading')
cube(p,F_gamma,H)
xlim([p(1) p(end)]);ylim([F_gamma(1) F_gamma(end)]);zlim([H(1) H(end)])
xlabel('[d_p 9]');ylabel('\gamma_{1,2}');zlabel('\theta_p (degrees)')
set(gca,'FontSize',14)
xlhand = get(gca,'xlabel');
set(xlhand,'fontsize',14)
ylhand = get(gca,'ylabel');
set(ylhand,'fontsize',14)
zlhand = get(gca,'zlabel');
set(zlhand,'fontsize',14)
hold off

saveas(gcf, 'figures/box_limits_ISE_reduced_time_fixed', 'fig')

if isempty(opt_worse)
    disp('Only improvements')
else
figure(88)
cube(p,F_gamma,H)
hold on
plot3(opt_worse(:,1),opt_worse(:,2),opt_worse(:,3),'o');
xlabel('[d_p 9]');ylabel('\gamma_{1,2}');zlabel('\theta_p (degrees)')
xlim([p(1) p(end)]);ylim([F_gamma(1) F_gamma(end)]);zlim([H(1) H(end)])
hold off
set_font
saveas(gcf, 'figures/box_limits_worse_reduced_time_fixed', 'fig')
end

