%% Predictive simulation, heading vs force contour plots
%
% Created by: Christoffer Ofstad 20.02.2014
%
%% Init
clear
%Real Ice Force applied
F_ice=5e4;
displacement=[20 9];
AoA_ice=10;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=400;

%% Initialize test parameters
delta=10;
d_pred=displacement; 
t=2.5;
constants.pred.timeoff=constants.real_ice.timeon;
simulation_model = ('sim_prediction_report_test'); 
sim_length=700;
init
find_available_thrust

%Find error without prediction
constants.pred.force=pred_force(0,[0 0],0);
constants.pred.timeon=0;
sim(simulation_model);
[total_error_no_pred, ~] = error_sampling(eta, ISE_eta);

%Initialize limits for time
a0=AoA_ice-30;
af=AoA_ice+30;
a=a0:(af-a0)/(delta-1):af;

%Initialize limits for force
f0_gamma1=1;
ff_gamma2=3.5;
F_gamma=f0_gamma1:(ff_gamma2-f0_gamma1)/(delta-1):ff_gamma2;


%% Time vs Force
%Initialize error vector
error_pos=zeros(delta);
error_head=zeros(delta);
count=0;
start_time=tic;
for i=1:length(a)
    for j=1:length(F_gamma)
        constants.pred.force=pred_force(F_gamma(i)*F_ice,d_pred,a(j));
        constants.pred.timeon=constants.pred.timeoff-t;
        %Simulation
        sim_start=tic;
        sim(simulation_model);
        sim_time=toc(sim_start);
        [total_error, ~] = error_sampling(eta, ISE_eta);
        error_pos(i,j)=total_error(4)/total_error_no_pred(4);
        error_head(i,j)=total_error(3)/total_error_no_pred(3);
        count=count+1;
        clc
        string = [num2str(round(100*((count)/(length(a)*length(F_gamma))))),'% complete'];
        string2= [secs2hms(abs(sim_time*(length(a)*length(F_gamma))-toc(start_time))),' remaining'];
        disp(string);
        disp(string2);
    end
end

figure(33)
contour3(a,F_gamma,error_pos,1000)
xlabel('\theta_p (degrees)');ylabel('\gamma_{1,2}');zlabel('position error ratio')
set_font
saveas(gcf, 'figures/box_limits_heading_vs_force_pos_contour', 'fig')

figure(44)
contour3(a,F_gamma,error_head,1000)
xlabel('\theta_p (degrees)');ylabel('\gamma_{1,2}');zlabel('heading error ratio')
set_font
saveas(gcf, 'figures/box_limits_heading_vs_force_head_contour', 'fig')
% set(gcf,'PaperUnits','inches','PaperPosition',[0 0 6 6])
% print -dbmp filename.bmp -r80
