%% Predictive simulation, time vs force contour plots
%
% Created by: Christoffer Ofstad 20.02.2014
%
%% Init
clear
%Real Ice Force applied
F_ice=5e4;
displacement=[-5 -9];
AoA_ice=-100;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=400;

%% Initialize test parameters
delta=10;
d_pred=displacement; 
AoA_pred=AoA_ice;
constants.pred.timeoff=constants.real_ice.timeon;
simulation_model = ('sim_prediction_report_test'); 
sim_length=700;
init
find_available_thrust

%Find error without prediction
constants.pred.force=pred_force(0,[0 0],0);
constants.pred.timeon=0;
sim(simulation_model);
[total_error_no_pred, ~] = error_sampling(eta, ISE_eta);

%Initialize limits for time
t0=1.5;
tf=3.5;
t=t0:(tf-t0)/(delta-1):tf;

%Initialize limits for force
f0_gamma1=1;
ff_gamma2=3.5;
F_gamma=f0_gamma1:(ff_gamma2-f0_gamma1)/(delta-1):ff_gamma2;


%% Time vs Force
%Initialize error vector
error_pos=zeros(delta);
error_head=zeros(delta);
count=0;
start_time=tic;
for i=1:length(t)
    for j=1:length(F_gamma)
        constants.pred.force=pred_force(F_gamma(i)*F_ice,d_pred,AoA_pred);
        constants.pred.timeon=constants.pred.timeoff-t(j);
        %Simulation
        sim_start=tic;
        sim(simulation_model);
        sim_time=toc(sim_start);
        [total_error, ~] = error_sampling(eta, ISE_eta);
        error_pos(i,j)=total_error(4)/total_error_no_pred(4);
        error_head(i,j)=total_error(3)/total_error_no_pred(3);
        count=count+1;
        clc
        string = [num2str(round(100*((count)/(length(t)*length(F_gamma))))),'% complete'];
        string2= [secs2hms(abs(sim_time*(length(t)*length(F_gamma))-toc(start_time))),' remaining'];
        disp(string);
        disp(string2);
    end
end
figure(1)
surf(t,F_gamma,error_pos,gradient(error_pos))
xlabel('t_p (seconds)');ylabel('\gamma_{1,2}');zlabel('position error ratio')
set_font
saveas(gcf, 'figures/box_limits_time_vs_force_pos', 'fig')

figure(2)
surf(t,F_gamma,error_head,gradient(error_head))
xlabel('t_p (seconds)');ylabel('\gamma_{1,2}');zlabel('heading error ratio')
set_font
saveas(gcf, 'figures/box_limits_time_vs_force_head', 'fig')

figure(33)
contour3(t,F_gamma,error_pos,1000)
xlabel('t_p (seconds)');ylabel('\gamma_{1,2}');zlabel('position error ratio')
set_font
saveas(gcf, 'figures/box_limits_time_vs_force_pos_contour', 'fig')

